
#
# Check for NVIDIA's Gelato(tm) runtime support.
#

AC_DEFUN([AC_CHECK_GELATO_RUNTIME],[
	AC_ARG_WITH(gelatoprefix, AC_HELP_STRING([--with-gelatoprefix], [NVIDIA Gelato(tm) installation prefix directory]),[],with_gelatoprefix="/opt/nvidia")

	AC_ARG_ENABLE(gelato, AC_HELP_STRING([--disable-gelato], [disable NVIDIA Gelato(tm) dependent parts]),
		[enablegelato=$enableval],
		[enablegelato=yes])

	if test x$enablegelato = "xyes" ; then
		save_CPPFLAGS="$CPPFLAGS"
		CPPFLAGS="$CPPFLAGS -I${with_gelatoprefix}/gelato/include"

		save_CXXFLAGS="$CXXFLAGS"
		CXXFLAGS="$CXXFLAGS -I${with_gelatoprefix}/gelato/include"
		
		save_LDFLAGS="$LDFLAGS"
		LDFLAGS="$LDFLAGS -L${with_gelatoprefix}/gelato/lib"
		
		save_LIBS="$LIBS"
		LIBS="$LIBS -lgelato"

		AC_MSG_CHECKING(for GelatoAPI::CreateRenderer in -lgelato)

		AC_LANG(C++)
		AC_TRY_LINK([#include <gelatoapi.h>], [GelatoAPI::CreateRenderer( )],
			[AC_MSG_RESULT(yes)
			 AC_CHECK_HEADER(gelatoapi.h,
				[ac_have_gelato="yes" GELATO_LIBS="-lgelato" AC_DEFINE(HAVE_GELATO_RUNTIME,1,[Define this if you have NVIDIA Gelato(tm) runtime support])],
				[AC_MSG_ERROR([*** NVIDIA Gelato(tm) runtime is available but no development headers. Please check your Gelato(tm) installation ***])])],
			[AC_MSG_RESULT(no) 
			 AC_MSG_WARN([*** NVIDIA Gelato(tm) runtime is not available. All Gelato(tm) dependent parts will be disabled ***])])

		if test x$ac_have_gelato = "xyes"; then
			ac_use_gelato=yes
			
			GELATO_INCLUDE_PATH="-I${with_gelatoprefix}/gelato/include"
			GELATO_LIB_PATH="-L${with_gelatoprefix}/gelato/lib"
		fi
		
		CPPFLAGS="$save_CPPFLAGS"
		CXXFLAGS="$save_CXXFLAGS"
		LDFLAGS="$save_LDFLAGS"
		LIBS="$save_LIBS"
	fi

	AC_SUBST(GELATO_INCLUDE_PATH)
	AC_SUBST(GELATO_LIB_PATH)
	AC_SUBST(GELATO_LIBS)
	AM_CONDITIONAL(HAVE_GELATO_RUNTIME, [test x$ac_use_gelato = "xyes"])

	if test x$ac_use_gelato = "xyes"; then
		ifelse([$1], , :, [$1])
	else
		ifelse([$2], , :, [$2])
	fi
])
